@@ -334,7 +334,7 @@ IdfGeometry <- R6Class("IdfGeometry", cloneable = FALSE,
         #'
         #' * `"surface_type"`: Default. Render the model by surface type model.
         #'   Walls, roofs, windows, doors, floors, and shading surfaces will
-        #'   have unqiue colors.
+        #'   have unique colors.
         #' * `"boundary"`: Render the model by outside boundary condition. Only
         #'   surfaces that have boundary conditions will be rendered with a
         #'   color. All other surfaces will be white.
@@ -561,10 +561,19 @@ idfgeom_convert <- function (self, private, type = c("surface", "subsurface", "s
 # }}}
 # idfgeom_round_digits {{{
 idfgeom_round_digits <- function (self, private, digits = 4L) {
-    meta <- rbindlist(list(
-        fast_subset(private$m_geoms$surface, c("id", "class")),
-        fast_subset(private$m_geoms$subsurface, c("id", "class")),
-        fast_subset(private$m_geoms$shading, c("id", "class"))
+    zone <- data.table()
+    origin <- data.table()
+    if (nrow(private$m_geoms$zone)) {
+        zone <- data.table(id = private$m_geoms$zone$id, class = "Zone")
+        origin <- private$m_geoms$zone[, .SD, .SDcols = c("id", "x", "y", "z")]
+        set(origin, NULL, "index", 1L)
+    }
+
+    check_empty <- function (dt) if (!nrow(dt)) data.table() else dt
+    meta <- rbindlist(list(zone,
+        check_empty(fast_subset(private$m_geoms$surface, c("id", "class"))),
+        check_empty(fast_subset(private$m_geoms$subsurface, c("id", "class"))),
+        check_empty(fast_subset(private$m_geoms$shading, c("id", "class")))
     ))
 
     # add a uuid
@@ -574,7 +583,8 @@ idfgeom_round_digits <- function (self, private, digits = 4L) {
     private$log_parent_uuid()
     private$log_parent_order()
 
-    set_geom_vertices(private$m_parent, list(meta = meta, vertices = private$m_geoms$vertices))
+    vert <- rbindlist(list(private$m_geoms$vertices, origin), use.names = TRUE)
+    set_geom_vertices(private$m_parent, list(meta = meta, vertices = vert), digits = digits)
 
     invisible(private$m_parent)
 }
@@ -610,6 +620,10 @@ idfgeom_cal_property <- function (self, private, class = NULL, object = NULL, fu
         ))
     }
 
+    # remove daylighting points
+    if (NROW(geoms$daylighting_point)) {
+        geoms$vertices <- geoms$vertices[!J(geoms$daylighting_point$id), on = "id"]
+    }
     prop <- get_newall_vector(geoms$vertices)[, by = "id", list(property = fun(c(x, y, z)))]
 
     add_zone_name(geoms)
@@ -697,10 +711,10 @@ idfgeom_print <- function (self, private) {
     cli::cat_line(sprintf(" * Building: '%s'", geoms$building$name))
     cli::cat_line(sprintf(" * North Axis: %s\u00B0", geoms$building$north_axis))
     cli::cat_line(sprintf(" * Zone Num: %s", NROW(geoms$zone)))
-    cli::cat_line(sprintf(" * Surface Num: %s", NROW(geoms$surface$meta)))
-    cli::cat_line(sprintf(" * SubSurface Num: %s", NROW(geoms$subsurface$meta)))
-    cli::cat_line(sprintf(" * Shading Num: %s", NROW(geoms$shading$meta)))
-    cli::cat_line(sprintf(" * Dayl Ref Pnt Num: %s", NROW(geoms$daylighting_point$meta)))
+    cli::cat_line(sprintf(" * Surface Num: %s", NROW(geoms$surface)))
+    cli::cat_line(sprintf(" * SubSurface Num: %s", NROW(geoms$subsurface)))
+    cli::cat_line(sprintf(" * Shading Num: %s", NROW(geoms$shading)))
+    cli::cat_line(sprintf(" * Dayl Ref Pnt Num: %s", NROW(geoms$daylighting_point)))
     cli::cat_line(" * Coordinate System:")
     cli::cat_line(c(
         sprintf("   - Detailed: '%s'", ifelse(geoms$rules$coordinate_system == "absolute", "Absolute", "Relative")),
