@@ -110,39 +110,33 @@ get_sql_report_data_dict <- function (sql) {
 # }}}
 # get_sql_report_data {{{
 #' @importFrom checkmate assert_scalar
-get_sql_report_data <- function (sql, csv = NULL, key_value = NULL, name = NULL, year = NULL,
+get_sql_report_data <- function (sql, key_value = NULL, name = NULL, year = NULL,
                                  tz = "UTC", case = "auto", all = FALSE, wide = FALSE,
                                  period = NULL, month = NULL, day = NULL, hour = NULL, minute = NULL,
                                  interval = NULL, simulation_days = NULL, day_type = NULL,
-                                 environment_name = NULL) {
+                                 environment_name = NULL, index = NULL) {
     dict <- read_sql_table(sql, "ReportDataDictionary")
     env <- read_sql_table(sql, "EnvironmentPeriods")
     time <- read_sql_table(sql, "Time")
 
-    if (!is.null(csv)) {
-        timestep <- read_sql_table(sql, "Simulations")$num_timesteps_per_hour
-        res <- read_report_data_csv(csv, env, dict, time,
-            key_value = key_value, name = name,
-            year = year, tz = tz, period = period,
-            month = month, day = day, hour = hour, minute = minute,
-            interval = interval, simulation_days = simulation_days,
-            environment_name = environment_name,
-            day_type = day_type, wide = wide, all = all, timestep = timestep)
-    } else {
-        res <- read_report_data_sql(sql, env, dict, time,
-            key_value = key_value, name = name,
-            year = year, tz = tz, period = period,
-            month = month, day = day, hour = hour, minute = minute,
-            interval = interval, simulation_days = simulation_days,
-            environment_name = environment_name,
-            day_type = day_type, wide = wide, all = all)
-    }
+    res <- read_report_data_sql(sql, env, dict, time,
+        key_value = key_value, name = name,
+        year = year, tz = tz, period = period,
+        month = month, day = day, hour = hour, minute = minute,
+        interval = interval, simulation_days = simulation_days,
+        environment_name = environment_name,
+        day_type = day_type, wide = wide, all = all)
 
     if (!is.null(case)) {
         assert_scalar(case)
         case_name <- as.character(case)
         set(res, NULL, "case", case_name)
-        setcolorder(res, c("case", setdiff(names(res), "case")))
+        setcolorder(res, "case")
+    }
+    if (!is.null(index)) {
+        assert_int(index)
+        set(res, NULL, "index", index)
+        setcolorder(res, "index")
     }
 
     res
@@ -152,7 +146,7 @@ get_sql_report_data <- function (sql, csv = NULL, key_value = NULL, name = NULL,
 #' @importFrom checkmate assert_scalar
 get_sql_tabular_data <- function (sql, report_name = NULL, report_for = NULL,
                                   table_name = NULL, column_name = NULL, row_name = NULL,
-                                  case = "auto", wide = FALSE, string_value = !wide) {
+                                  case = "auto", wide = FALSE, string_value = !wide, index = NULL) {
     q <- get_sql_tabular_data_query(report_name, report_for, table_name, column_name, row_name)
     dt <- setnames(get_sql_query(sql, q), "tabular_data_index", "index")[]
 
@@ -160,7 +154,12 @@ get_sql_tabular_data <- function (sql, report_name = NULL, report_for = NULL,
         assert_scalar(case)
         case_name <- as.character(case)
         set(dt, NULL, "case", case_name)
-        setcolorder(dt, c("case", setdiff(names(dt), "case")))
+        setcolorder(dt, "case")
+    }
+    if (!is.null(index)) {
+        assert_int(index)
+        set(dt, NULL, "index", index)
+        setcolorder(dt, "index")
     }
 
     if (!wide) return(dt)
@@ -204,7 +203,7 @@ subset_sql_time <- function (time, year = NULL, tz = "UTC", period = NULL,
     subset_time <- FALSE
 
     # store day of week for the first simulation day
-    if (datetime && is.null(year) && !"year" %chin% names(time)) {
+    if (datetime && is.null(year)) {
         # get wday of first simulation day per environment
         w <- time[SIMULATION_DAYS == 1L & !is.na(DAY_TYPE), .SD[1L],
             .SDcols = c("MONTH", "DAY", "DAY_TYPE", "ENVIRONMENT_PERIOD_INDEX"),
@@ -348,31 +347,31 @@ create_sql_datetime <- function (time, first_day = NULL, year = NULL, tz = "UTC"
 
         if ("year" %in% names(time)) {
             time[J(0L), on = "year", year := NA_integer_]
+        }
+
+        setnames(first_day, tolower(names(first_day)))
+
+        # in case there is no valid day type
+        if (!nrow(first_day)) {
+            # directly assign current year
+            set(time, NULL, "year", cur_year)
         } else {
-            setnames(first_day, tolower(names(first_day)))
+            set(first_day, NULL, "date", lubridate::make_date(cur_year, first_day$month, first_day$day))
+            set(first_day, NULL, "dt", get_epw_wday(first_day$day_type))
 
-            # in case there is no valid day type
-            if (!nrow(first_day)) {
-                # directly assign current year
-                set(time, NULL, "year", cur_year)
-            } else {
-                set(first_day, NULL, "date", lubridate::make_date(cur_year, first_day$month, first_day$day))
-                set(first_day, NULL, "dt", get_epw_wday(first_day$day_type))
+            # check leap year
+            leap <- time[J(2L, 29L), on = c("month", "day"), nomatch = NULL, .N > 0]
 
-                # check leap year
-                leap <- time[J(2L, 29L), on = c("month", "day"), nomatch = NULL, .N > 0]
-
-                if (any(!is.na(first_day$dt))) {
-                    for (i in which(!is.na(first_day$dt))) {
-                        set(first_day, i, "year", find_nearst_wday_year(first_day$date[i], first_day$dt[i], cur_year, leap))
-                    }
+            if (any(!is.na(first_day$dt))) {
+                for (i in which(!is.na(first_day$dt))) {
+                    set(first_day, i, "year", find_nearst_wday_year(first_day$date[i], first_day$dt[i], cur_year, leap))
                 }
-
-                # make sure all environments have a year value
-                first_day[is.na(dt), year := lubridate::year(Sys.Date())]
-
-                set(time, NULL, "year", first_day[J(time$environment_period_index), on = "environment_period_index", year])
             }
+
+            # make sure all environments have a year value
+            first_day[is.na(dt), year := lubridate::year(Sys.Date())]
+
+            set(time, NULL, "year", first_day[J(time$environment_period_index), on = "environment_period_index", year])
         }
 
         # for SummerDesignDay and WinterDesignDay, directly use current year
@@ -479,313 +478,6 @@ tidy_sql_name <- function (x) {
     setnames(x, stri_sub(gsub("([A-Z])", "_\\L\\1", names(x), perl = TRUE), 2L))
 }
 # }}}
-# read_report_data_csv {{{
-read_report_data_csv <- function (csv, env, dict, time,
-                                  # dict
-                                  key_value = NULL, name = NULL,
-                                  # time
-                                  year = NULL, tz = "UTC", period = NULL,
-                                  month = NULL, day = NULL, hour = NULL, minute = NULL,
-                                  interval = NULL, simulation_days = NULL, day_type = NULL,
-                                  # run period
-                                  environment_name = NULL,
-                                  all = FALSE, wide = FALSE, timestep = NULL) {
-    # get start row and number of rows to read using fread before subsetting
-    # use the more detailed one for row subsetting
-    int <- min(get_sql_reporting_freq(dict$reporting_frequency))
-
-    # handle RunPeriod frequency
-    time <- complete_sql_time(time)
-
-    # get time data used for row subsetting
-    # should check if detailed output is required
-    # in this case, interval_type for TimeStep will also be -1 but not 0
-    # timestep is in the time table
-    if (int == RPFREQ["Each Call"] | int == RPFREQ["TimeStep"]) {
-        time_csv <- unique(time[J(RPFREQ["Each Call"]), on = "interval_type"], by = c("environment_period_index", "month", "day", "hour", "minute"))
-    } else {
-        time_csv <- time[J(int), on = "interval_type", nomatch = NULL]
-    }
-
-    # store all time index in case used when fread failed to detect correct
-    # column numbers
-    time_index_all <- time_csv$time_index
-
-    dict <- subset_sql_report_data_dict(dict, key_value = key_value, name = name)
-    env <- subset_sql_environment_periods(env, environment_name = environment_name)
-
-    subset_var <- attr(dict, "filtered")
-    subset_env <- attr(env, "filtered")
-
-    time_csv <- time_csv[env, on = "environment_period_index", nomatch = NULL]
-
-    # create datetime column
-    # necessary for running 'complete_sql_time'
-    if (is.null(year) && !"year" %chin% names(time_csv)) {
-        # get wday of first simulation day per environment
-        w <- time_csv[simulation_days == 1L & !is.na(day_type), .SD[1L],
-            .SDcols = c("month", "day", "day_type", "environment_period_index"),
-            by = "environment_period_index"
-        ][!J(c("WinterDesignDay", "SummerDesignDay")), on = "day_type"]
-    }
-
-    # create target columns
-    dict <- add_csv_variable(dict)
-
-    # read csv header
-    vars <- names(fread(csv, nrows = 0, sep = ","))
-
-    # in case the *:MeterFileOnly
-    if (length(vars) < nrow(dict)) dict <- dict[Variable %chin% vars]
-
-    # get the interval type for target variables
-    int_var <- get_sql_reporting_freq(dict$reporting_frequency)
-
-    # subset time using input to get the target time index
-    time_sub <- subset_sql_time(time_csv, year = year, tz = tz, period = period,
-        month = month, day = day, hour = hour, minute = minute,
-        interval = interval, simulation_days = simulation_days,
-        day_type = day_type)
-    subset_time <- attr(time_sub, "filtered") || subset_env
-
-    # subset_sql_time will change column names to upper case
-    setnames(time_csv, stri_trans_tolower(names(time_csv)))
-
-    # get the row index
-    if (!subset_time) {
-        skip <- "__auto__"
-        nrows <- Inf
-    } else if (!nrow(time_sub)) {
-        skip <- "__auto__"
-        nrows <- 0
-    } else {
-        range <- range(time_sub$time_index)
-        range_csv <- match(range, time_csv$time_index)
-        # count from the header row which is 1
-        skip <- range_csv[1L]
-        nrows <- range_csv[2L] - skip + 1L
-    }
-
-    # get target csv column indices and names
-    if (!subset_var) {
-        select <- NULL
-        col.names <- vars
-    } else {
-        # append "Date/Time"
-        select <- which(vars %chin% c("Date/Time", dict$Variable))
-        col.names <- vars[select]
-    }
-
-    if (!nrow(dict)) {
-        data <- data.table("Date/Time" = character())
-    } else {
-        # read actual data
-        if (skip == "__auto__" || length(unique(int_var)) == 1L) {
-            data <- fread(csv, sep = ",", fill = TRUE, skip = skip, nrows = nrows,
-                select = select, col.names = col.names)
-        } else {
-            first <- fread(csv, sep = ",", fill = TRUE, skip = skip, nrows = 1L, header = FALSE)
-
-            if (ncol(first) == length(col.names)) {
-                data <- fread(csv, sep = ",", fill = TRUE, skip = skip, nrows = nrows,
-                    select = select, col.names = col.names)
-            } else {
-                data <- fread(csv, sep = ",", fill = TRUE, header = TRUE,
-                    select = select, col.names = col.names)
-                set(data, NULL, "time_index", time_index_all)
-                data <- data[J(time_sub$time_index), on = "time_index"]
-            }
-        }
-    }
-
-    # subet using time index
-    if (!subset_time) {
-        set(data, NULL, "time_index", time_sub$time_index)
-    } else if (!nrow(time_sub)) {
-        set(data, NULL, "time_index", integer())
-    } else {
-        set(data, NULL, "time_index", time_csv$time_index[range_csv[[1L]]:range_csv[[2L]]])
-        data <- data[J(time_sub$time_index), on = "time_index"]
-    }
-
-    subset_by_interval <- function (data, interval, timestep = NULL) {
-        if (interval %in% RPFREQ["Annual"]) {
-            data <- data[, .SD[.N], by = "environment_period_index"]
-        } else if (interval %in% RPFREQ["RunPeriod"]) {
-            data <- data[, .SD[.N], by = "environment_period_index"]
-        } else if (interval == RPFREQ["Monthly"]) {
-            data <- data[, .SD[.N], by = c("environment_period_index", "month")]
-        } else if (interval == RPFREQ["Daily"]) {
-            data <- data[J(24L, 0L), on = c("hour", "minute")]
-        } else if (interval == RPFREQ["Hourly"]) {
-            data <- data[J(0L), on = "minute"]
-        } else if (interval == RPFREQ["TimeStep"]) {
-            cols <- names(data)
-            int <- as.integer(60 / timestep)
-            tm <- data[, by = "environment_period_index", {
-                r <- range(datetime)
-                list(datetime = seq(r[[1L]], r[[2L]], by = paste(int, "mins")))
-            }]
-            data <- tm[data, on = c("environment_period_index", "datetime"), mult = "first", nomatch = NULL]
-            setcolorder(data, cols)
-        }
-        data
-    }
-
-    # save to keep NAs
-    if (wide) {
-        if (length(int_var)) {
-            int_var <- min(int_var)
-            if (int != int_var) {
-                time_sub <- time[J(int_var), on = "interval_type"]
-                # should re-subset based on targeting environment
-                time_sub <- time_sub[env, on = "environment_period_index", nomatch = NULL]
-
-                if (subset_time) {
-                    time_sub <- subset_sql_time(time_sub, year = year, tz = tz, period = period,
-                        month = month, day = day, hour = hour, minute = minute,
-                        interval = interval, simulation_days = simulation_days,
-                        day_type = day_type)
-                }
-
-                data <- subset_by_interval(data, int_var)
-                set(data, NULL, "time_index", time_sub$time_index)
-            }
-        }
-
-        # use dict order
-        setcolorder(data, c("Date/Time", dict$Variable))
-
-        if (!all) {
-            set(data, NULL, "time_index", NULL)
-        } else {
-            cols <- c("environment_period_index", "environment_name", "simulation_days",
-                "datetime", "month", "day", "hour", "minute", "day_type"
-            )
-            add_joined_cols(time_sub, data, "time_index", cols)
-            set(data, NULL, "time_index", NULL)
-            setcolorder(data, cols)
-        }
-
-    # if data frequency is not the same as variable frequency, should re-subset
-    } else {
-        # remove 'Date/Time'
-        set(data, NULL, "Date/Time", NULL)
-
-        # should handle separately by each frequency
-        set(dict, NULL, "interval_type", int_var)
-
-        melt_data <- function (data, int_per, dict_per, time_per) {
-            if (!nrow(time_per)) return(data.table(time_index = integer(), report_data_dictionary_index = integer(), value = double()))
-
-            cols <- setdiff(names(data), setdiff(dict$Variable, dict_per$Variable))
-            data <- subset_by_interval(fast_subset(data, cols), int_per, timestep)
-
-            # remove time components after subsetting
-            set(data, NULL, names(time_per), NULL)
-            # update time index
-            set(data, NULL, "time_index", time_per$time_index)
-
-            # add report data dictionary index
-            setnames(data, dict_per$Variable, as.character(dict_per$report_data_dictionary_index))
-
-            data <- melt.data.table(data, id.vars = "time_index",
-                measure.vars = as.character(dict_per$report_data_dictionary_index),
-                variable.name = "report_data_dictionary_index", variable.factor = TRUE
-            )
-
-            # convert index to integer back
-            set(data, NULL, "report_data_dictionary_index",
-                .subset(
-                    dict_per$report_data_dictionary_index,
-                    as.integer(data$report_data_dictionary_index)
-                )
-            )
-            data
-        }
-
-        if (!nrow(data)) {
-            data <- data.table(time_index = integer(), report_data_dictionary_index = character(), value = double())
-        } else {
-            # add time column for further subsetting
-            set(data, NULL, names(time_sub), time_sub)
-
-            # get time table for each frequency
-            l <- lapply(split(dict, by = "interval_type"), function (dict_per) {
-                # for 'Each Call' there is no way to distinguish between Zone time
-                # step and HVAC time step
-                # see: https://github.com/NREL/EnergyPlus/issues/8227
-                int_per <- dict_per$interval_type[[1L]]
-                # same as the interval in the csv
-                if (int_per == int) {
-                    time_per <- time_sub
-                    if (int_per != RPFREQ["Each Call"]) {
-                        data <- melt_data(data, int_per, dict_per, time_per)
-                    } else {
-                        # manually separate variables output in zone and hvac
-                        # timestep
-                        is_zone <- vlapply(fast_subset(data, dict_per$Variable), anyNA)
-                        time_zone <- subset_by_interval(time_per, RPFREQ["TimeStep"], timestep)
-                        set(time_zone, NULL, "interval", as.integer(60 / timestep))
-                        set(time_zone, NULL, "time_index", -time_zone$time_index)
-
-                        data <- rbindlist(list(
-                            melt_data(data, RPFREQ["TimeStep"], dict_per[is_zone][, interval_type := RPFREQ["TimeStep"]], time_zone),
-                            melt_data(data, int_per, dict_per[!is_zone], time_per)
-                        ))
-                        time_per <- rbindlist(list(time_zone, time_per))
-                    }
-                } else {
-                    time_int <- subset_by_interval(time_sub, int_per, timestep)
-
-                    time_per <- time[J(int_per), on = "interval_type"]
-                    # should re-subset based on targeting environment
-                    time_per <- time_per[env, on = "environment_period_index", nomatch = NULL]
-                    time_per <- subset_sql_time(time_per, year = year, tz = tz,
-                        period = period, month = month, day = day, hour = hour,
-                        minute = minute, interval = interval,
-                        simulation_days = simulation_days, day_type = day_type,
-                        datetime = FALSE)
-                    # keep original datetime and day type
-                    set(time_per, NULL, c("datetime", "day_type"), list(time_int$datetime, time_int$day_type))
-
-                    set(data, NULL, "interval_type", int_per)
-
-                    data <- melt_data(data, int_per, dict_per, time_per)
-                }
-
-                list(data = data, time = time_per)
-            })
-
-            data <- rbindlist(lapply(l, .subset2, "data"))
-            time_sub <- rbindlist(lapply(l, .subset2, "time"))
-        }
-
-        if (!all) {
-            cols_time <- "datetime"
-            cols_dict <- c("key_value", "name", "units")
-        } else {
-            cols_time <- c("datetime", "month", "day", "hour", "minute", "dst",
-                "interval", "simulation_days", "day_type", "environment_name",
-                "environment_period_index")
-            cols_dict <- c("is_meter", "type", "index_group", "timestep_type",
-                "key_value", "name", "reporting_frequency", "schedule_name",
-                "units")
-        }
-
-        add_joined_cols(time_sub, data, "time_index", cols_time)
-        data[time_index < 0L, time_index := -time_index]
-
-        add_joined_cols(dict, data, "report_data_dictionary_index", cols_dict)
-
-        setorderv(data, c("report_data_dictionary_index", "time_index"))
-        set(data, NULL, c("report_data_dictionary_index", "time_index"), NULL)
-        setcolorder(data, c(cols_time, cols_dict))
-    }
-
-    data
-}
-# }}}
 # read_report_data_sql {{{
 read_report_data_sql <- function (sql, env, dict, time,
                                   # dict
